/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */


package com.openexchange.documentconverter;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.HashMap;

//--------
//- IJob -
//--------

/**
 * {@link IJob}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */
public interface IJob {

    /**
     * @return The hash value, upon which this job (-result) can be uniquely identified
     */
    public String getHash();

    /**
     * @param jobProperties Additional job properties to be added to this job; may be called more than once
     */
    void addJobProperties(HashMap<String, Object> jobProperties);

    /**
     * @return The current job properties
     */
    HashMap<String, Object> getJobProperties();

    /**
     * @param jobProperties Additional job properties to be added to this job; may be called more than once
     */
    void addResultProperties(HashMap<String, Object> jobResultProperties);

    /**
     * @return The current job properties
     */
    HashMap<String, Object> getResultProperties();

    /**
     * @return The type of engine, the current job is assigned to
     */
    abstract EngineType engineTypeNeeded();

    /**
     * This method will be called in order to let the job do the real work
     *
     * @param jobExecutionData
     * @return
     * @throws InterruptedException
     * @throws IOException
     * @throws MalformedURLException
     * @throws Exception
     */
    abstract boolean execute(Object jobExecutionData) throws InterruptedException, IOException, MalformedURLException, Exception;

    abstract void kill() throws Exception;
}
